@@ -19,7 +19,6 @@ from contextlib import contextmanager
 from unittest.mock import patch
 
 import _pytest.tmpdir
-import pkg_resources
 import py.path
 import requests
 
@@ -142,11 +141,10 @@ def _copy_dir(target_dir, src_dir, on_duplicate="exception", keep_top_dir=False)
 
     if keep_top_dir:
         src_files = src_dir
+    elif src_dir.isdir():
+        src_files.extend(src_dir.listdir())
     else:
-        if src_dir.isdir():
-            src_files.extend(src_dir.listdir())
-        else:
-            src_files.append(src_dir)
+        src_files.append(src_dir)
 
     for entry in src_files:
         target_entry = target_dir / entry.basename
@@ -183,7 +181,7 @@ def initialize_git_repo_and_commit(project_dir, verbose=True):
             ["git", "reset", ".gitignore"],
             ["git", "commit", "-m", "Initial commit"],
         ]:
-            subprocess.run(cmd, stdout=None if verbose else subprocess.PIPE)
+            subprocess.run(cmd, stdout=None if verbose else subprocess.PIPE, check=True)
 
 
 def prepare_project(project, tmp_project_dir, force=False):
@@ -217,7 +215,7 @@ def execute_setup_py(project_dir, setup_args, disable_languages_test=False):
     """
 
     # See https://stackoverflow.com/questions/9160227/dir-util-copy-tree-fails-after-shutil-rmtree
-    distutils.dir_util._path_created = {}  # type: ignore[attr-defined]
+    distutils.dir_util._path_created.clear()  # type: ignore[attr-defined]
 
     # Clear _PYTHON_HOST_PLATFORM to ensure value sets in skbuild.setuptools_wrap.setup() does not
     # influence other tests.
@@ -225,10 +223,6 @@ def execute_setup_py(project_dir, setup_args, disable_languages_test=False):
         del os.environ["_PYTHON_HOST_PLATFORM"]
 
     with push_dir(str(project_dir)), push_argv(["setup.py", *setup_args]), prepend_sys_path([str(project_dir)]):
-        # Restore master working set that is reset following call to "python setup.py test"
-        # See function "project_on_sys_path()" in setuptools.command.test
-        pkg_resources._initialize_master_working_set()  # type: ignore[attr-defined]
-
         with open("setup.py") as fp:
             setup_code = compile(fp.read(), "setup.py", mode="exec")
 
