@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from skbuild import setup
 
 setup(
@@ -8,5 +10,4 @@ setup(
     license="MIT",
     packages=["hello"],
     package_dir={"": "src"},
-    test_suite="hello_tests",
 )
