@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from skbuild import setup
 
 setup(
@@ -7,5 +9,4 @@ setup(
     author="The scikit-build team",
     license="MIT",
     packages=["hello"],
-    test_suite="hello_tests",
 )
