@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from skbuild import setup
 
 setup(
@@ -7,7 +9,6 @@ setup(
     author="The scikit-build team",
     license="MIT",
     packages=["hello"],
-    tests_require=[],
     setup_requires=[],
     cmake_source_dir="../../",
 )
