@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from skbuild import setup
 
 
@@ -12,7 +14,6 @@ setup(
     author="The scikit-build team",
     license="MIT",
     packages=["hello"],
-    tests_require=[],
     setup_requires=[],
     cmake_source_dir="../../",
     cmake_process_manifest_hook=exclude_dev_files,
