@@ -1,11 +1,11 @@
-#!/usr/bin/env python
-
 """test_hello_cpp
 ----------------------------------
 
 Tries to build and test the `hello-cpp` sample project.
 """
 
+from __future__ import annotations
+
 import glob
 import os
 
@@ -36,11 +36,6 @@ def test_hello_builds():
         another_run()
 
 
-# @project_setup_py_test("hello-cpp", ["test"])
-# def test_hello_works():
-#     pass
-
-
 @project_setup_py_test("hello-cpp", ["sdist"])
 def test_hello_sdist():
     sdists_tar = glob.glob("dist/*.tar.gz")
