@@ -21,27 +21,27 @@ def test_hello_pure_builds(capsys):
     assert "skipping skbuild (no CMakeLists.txt found)" in out
 
 
-# @project_setup_py_test("hello-pure", ["test"])
-# def test_hello_cython_works():
-#     pass
-
-
 @project_setup_py_test("hello-pure", ["sdist"], disable_languages_test=True)
 def test_hello_pure_sdist():
     sdists_tar = glob.glob("dist/*.tar.gz")
     sdists_zip = glob.glob("dist/*.zip")
     assert sdists_tar or sdists_zip
 
+    dirname = "hello-pure-1.2.3"
+    # setuptools 69.3.0 and above now canonicalize the filename as well.
+    if any("hello_pure" in x for x in sdists_zip + sdists_tar):
+        dirname = "hello_pure-1.2.3"
+
     expected_content = [
-        "hello-pure-1.2.3/hello/__init__.py",
-        "hello-pure-1.2.3/setup.py",
+        f"{dirname}/hello/__init__.py",
+        f"{dirname}/setup.py",
     ]
 
-    sdist_archive = "dist/hello-pure-1.2.3.zip"
+    sdist_archive = f"dist/{dirname}.zip"
     if sdists_tar:
-        sdist_archive = "dist/hello-pure-1.2.3.tar.gz"
+        sdist_archive = f"dist/{dirname}.tar.gz"
 
-    check_sdist_content(sdist_archive, "hello-pure-1.2.3", expected_content)
+    check_sdist_content(sdist_archive, dirname, expected_content)
 
 
 @project_setup_py_test("hello-pure", ["bdist_wheel"], disable_languages_test=True)
