@@ -1,14 +1,16 @@
+from __future__ import annotations
+
 import os
-import sys
+import platform
 
 import pytest
 
 from . import get_ext_suffix, project_setup_py_test
 
-PYPY = hasattr(sys, "implementation") and sys.implementation.name == "pypy"
 
-
-@pytest.mark.xfail(PYPY and sys.platform.startswith("darwin"), reason="Broken on PyPy on macOS")
+@pytest.mark.skipif(
+    platform.python_implementation() == "PyPy", reason="PyPy is reporting an empty linker, doesn't seem to be our fault"
+)
 @project_setup_py_test("issue-284-build-ext-inplace", ["build_ext", "--inplace"], disable_languages_test=True)
 def test_build_ext_inplace_command():
     assert os.path.exists(f"hello/_hello_sk{get_ext_suffix()}")
