@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import logging
 from types import SimpleNamespace
 
@@ -14,7 +16,7 @@ def test_hide_listing(caplog):
     distribution = SimpleNamespace()
     distribution.hide_listing = True
 
-    with distribution_hide_listing(distribution):
+    with distribution_hide_listing(distribution):  # type: ignore[arg-type]
         logging.getLogger("wheel").info("This is hidden")
 
     assert "This is hidden" not in caplog.text
@@ -26,7 +28,7 @@ def test_no_hide_listing(caplog):
     distribution = SimpleNamespace()
     distribution.hide_listing = False
 
-    with distribution_hide_listing(distribution):
+    with distribution_hide_listing(distribution):  # type: ignore[arg-type]
         logging.getLogger("wheel").info("This is not hidden")
 
     assert "This is not hidden" in caplog.text
