@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-
 """test_outside_project_root
 ----------------------------------
 
@@ -8,6 +6,8 @@ attempt fails with a SystemExit exception that has an SKBuildError exception as
 its value.
 """
 
+from __future__ import annotations
+
 import pytest
 
 from skbuild.exceptions import SKBuildError
