@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-
 """test_skbuild_variable
 ------------------------
 
@@ -7,6 +5,8 @@ Tries to build the `fail-unless-skbuild-set` sample project.  The CMake variable
 "SKBUILD" must be set in order for the build to succeed.
 """
 
+from __future__ import annotations
+
 from . import project_setup_py_test
 
 
@@ -15,11 +15,6 @@ def test_skbuild_variable_builds():
     pass
 
 
-# @project_setup_py_test("fail-unless-skbuild-set", ["test"], disable_languages_test=True)
-# def test_skbuild_variable_works():
-#     pass
-
-
 @project_setup_py_test("fail-unless-skbuild-set", ["sdist"], disable_languages_test=True)
 def test_skbuild_variable_sdist():
     pass
